@@ -3,6 +3,8 @@ import sys
 from gitit.add import add
 from gitit.branch import branch
 from gitit.commit import commit
+from gitit.push import push
+from gitit.tag import tag
 
 
 class ParseArgs:
@@ -11,13 +13,15 @@ class ParseArgs:
             prog='gitit',
             description='Facilitate the standardization of git commands in a project',
         )
-        self.subparsers = self.parser.add_subparsers(title='Commands')
+        self.branch_new_group = None
         self.parser_add_a = None
         self.parser_branch_new = None
         self.parser_commit_def = None
         self.parser_commit_cust = None
         self.parser_commit_pre = None
-        self.branch_new_group = None
+        self.parser_push = None
+        self.parser_push_tag = None
+        self.subparsers = self.parser.add_subparsers(title='Commands')
 
     def add_a(self):
         self.parser_add_a = self.subparsers.add_parser(
@@ -101,27 +105,79 @@ class ParseArgs:
     def commit_pre(self):
         self.parser_commit_pre = self.subparsers.add_parser(
             'commitpre',
-            help='Commit a branch with the default message.',
+            help='Commit a branch with a predefined message.',
         )
         self.parser_commit_pre.add_argument(
-            '-m',
-            '--msg',
+            'msg',
             choices=commit.CommitMsgs().dict().keys(),
             help='Commit a branch with a pre defined message.',
         )
         self.parser_commit_pre.set_defaults(func=commit.CommitPre)
         pass
 
+    def push_all(self):
+        self.parser_push = self.subparsers.add_parser(
+            'pushall',
+            help='Push master branch to the remote repository.',
+        )
+        self.parser_push.set_defaults(func=push.PushAll)
+        pass
+
+    def push_master(self):
+        self.parser_push = self.subparsers.add_parser(
+            'pushmaster',
+            help='Push master branch to the remote repository.',
+        )
+        self.parser_push.set_defaults(func=push.PushMaster)
+        pass
+
+    def push_tag(self):
+        self.parser_push_tag = self.subparsers.add_parser(
+            'pushtag',
+            help='Tag a branch and push it to the remote repository.',
+        )
+        self.parser_push_tag.add_argument(
+            '--release',
+            default=None,
+            help='Add a tag in the semantic version format (major.minor.patch).',
+        )
+        self.parser_push_tag.set_defaults(func=push.PushTag)
+        pass
+
+    def push_work(self):
+        self.parser_push = self.subparsers.add_parser(
+            'pushwork',
+            help='Push branch to the remote repository.',
+        )
+        self.parser_push.set_defaults(func=push.PushWork)
+        pass
+
+    def tag(self):
+        self.parser_tag = self.subparsers.add_parser(
+            'tag',
+            help='Tag a branch.',
+        )
+        self.parser_tag.add_argument(
+            'release',
+            help='Symantic release.',
+        )
+        self.parser_tag.set_defaults(func=tag.Tag)
+        pass
+
 
 def main():
     pa = ParseArgs()
     pa.add_a()
+    pa.branch_new()
     pa.commit_def()
     pa.commit_cust()
     pa.commit_pre()
-    pa.branch_new()
+    pa.push_all()
+    pa.push_master()
+    pa.push_tag()
+    pa.push_work()
+    pa.tag()
     if len(sys.argv) > 1:
-        # import pdb;pdb.set_trace()
         args = pa.parser.parse_args()
         args.func(args)
     else:
